Test Open
open | ../tests/html/test_open.html |
verifyLocation | */tests/html/test_open.html |
verifyLocation | regexp:.*/tests/html/[Tt]est_open.html |
verifyNotLocation | */foo.html |
verifyTextPresent | glob:This is a test of the open command. |
verifyTextPresent | This is a test of the open command. |
verifyTextPresent | exact:This is a test of |
verifyTextPresent | regexp:This is a test of |
verifyTextPresent | regexp:T*his is a test of |
verifyTextNotPresent | exact:XXXXThis is a test of |
verifyTextNotPresent | regexp:ThXXXXXXXXXis is a test of |
open | ../tests/html/test_page.slow.html |
verifyLocation | */tests/html/test_page.slow.html |
verifyTitle | Slow Loading Page |
setTimeout | 5000 |
open | ../tests/html/test_open.html |
open | ../tests/html/test_open.html |
open | ../tests/html/test_open.html |